==> ktp-accounts-kcm-22.04.2.tar.xz: ktp-accounts-kcm-22.04.2/plugins/rakia/ktpaccountskcm_plugin_rakia.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Rakia/SofiaSIP connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći Rakia/Sofia SIP menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració del compte personalitzat per a comptes que usen el gestor de connexions Rakia/SofiaSIP.
Comment[ca@valencia]=Interfície d'usuari de configuració del compte personalisat per a comptes que utilisen el gestor de connexions Rakia/SofiaSIP.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Raika/SofiaSIP.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Rakia/SofiaSIP.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Rakia/SofiaSIP-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Rakia/SofiaSIP.
Comment[en_GB]=Custom account configuration user interface for accounts using the Rakia/SofiaSIP connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Rakia/SofiaSIP.
Comment[et]=Rakia/SofiaSIP-i ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[eu]=Kontuak konfiguratzeko norberak finkaturiko erabiltzaile interfazea «Rakia/SofiaSIP» konexio kudeatzailea erabiltzen duten kontuetarako.
Comment[fi]=Rakia/SofiaSIP-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Rakia / SofiaSIP ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Rakia/SofiaSIP.
Comment[hu]=Egyedi beállítófelület a Rakia/SofiaSIP kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Rakia/SofiaSIP.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Rakia/SofiaSIP.
Comment[kk]=Rakia/SofiaSIP байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី​ផ្ទាល់ខ្លួន​សម្រាប់​គណនី​ដែល​ប្រើ​កម្មវិធី​គ្រប់គ្រង​ការ​តភ្ជាប់ Rakia/SofiaSIP ។
Comment[ko]=Rakia/SofiaSIP 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Rakia/SofiaSIP ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Rakia/SofiaSIP tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „Rakia/SofiaSIP“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Rakia/SofiaSIP verbindingenbeheerder gebruiken.
Comment[nn]=Brukarflate for å setja oppkontoar med Raika/SofiaSP tilkoplingshandsamar.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Rakia/SofiaSIP.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Rakia/SofiaSIP.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Rakia/SofiaSIP.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Rakia/SofiaSIP.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Rakia/SofiaSIP.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Rakia/SofiaSIP.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Rakia/SofiaSIP.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Ракија/СофијаСИП.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Ракија/СофијаСИП.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Rakia/SofiaSIP.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Rakia/SofiaSIP.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Rakia/SofiaSIP.
Comment[tr]=Rakia/SofiaSIP bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштування облікового запису за допомогою керування з’єднаннями Rakia/SofiaSIP.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes tot s' siervant do manaedjeu d' raloyaedje Rakia/SofiaSIP.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Rakia/SofiaSIP connection manager.xx
Comment[zh_CN]=通过 Rakia/SofiaSIP 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Rakia/SofiaSIP 連線管理員的帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Rakia/SofiaSIP Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Rakia/Sofia SIP
Name[ca]=Interfície d'usuari de configuració del compte de Rakia/SofiaSIP
Name[ca@valencia]=Interfície d'usuari de configuració del compte de Rakia/SofiaSIP
Name[cs]=Uživatelské rozhraní nastavení účtu Rakia/SofiaSIP
Name[da]=Brugerflade til Rakia/SofiaSIP kontokonfiguration
Name[de]=Benutzeroberfläche zur Einrichtung von Rakia/SofiaSIP-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη με Rakia/SofiaSIP
Name[en_GB]=Rakia/SofiaSIP Account Configuration User Interface
Name[es]=Interfaz de configuración de cuentas Rakia/SofiaSIP
Name[et]=Rakia/SofiaSIP-i konto seadistamise kasutajaliides
Name[eu]=«Rakia/SofiaSIP» kontuak konfiguratzeko erabiltzaile interfazea
Name[fi]=Rakia/SofiaSIP-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur pour la configuration de comptes « Rakia / SofiaSIP ».
Name[gl]=Interface de usuario para a configuración de contas de Rakia/SofiaSIP
Name[hu]=Rakia/SofiaSIP azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Rakia/SofiaSIP
Name[it]=Interfaccia utente di configurazione account Rakia/SofiaSIP
Name[kk]=Rakia/SofiaSIP тіркелгі пайдаланушы интерфейсін баптау
Name[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី Rakia/SofiaSIP
Name[ko]=Rakia/SofiaSIP 계정 설정 사용자 인터페이스
Name[lt]=Rakia/SofiaSIP paskyros konfigūravimo naudotojo sąsają
Name[nb]=Brukerflate for å sette opp Rakia/SofiaSIP-konto
Name[nds]=Rakia/SofiaSIP-Kontoinstellenböversiet
Name[nl]=Gebruikersinterface voor Rakia/SofiaSIP accountconfiguratie
Name[nn]=Brukarflate for å setja opp Radika/SofiaSIP-konto
Name[pl]=Nakładka graficzna do ustawiania konta Rakia/SofiaSIP
Name[pt]=Interface de Configuração de Contas do Rakia/SofiaSIP
Name[pt_BR]=Interface de configuração de contas do Rakia/SofiaSIP
Name[ro]=Interfață de configurare a conturilor Rakia/SofiaSIP
Name[ru]=Интерфейс для настройки учётной записи Rakia/SofiaSIP
Name[sk]=Používateľské rozhranie konfigurácie účtu Rakia/SofiaSIP
Name[sl]=Uporabniški vmesnik za nastavitev računov Rakia/SofiaSIP
Name[sr]=Корисничко сучеље за подешавање налога под Ракијом/СофијаСИП‑ом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Ракијом/СофијаСИП‑ом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod Rakijom/SofiaSIP‑om
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod Rakijom/SofiaSIP‑om
Name[sv]=Användargränssnitt för inställning av Rakia/SofiaSIP-konton
Name[tr]=Rakia/SofiaSIP Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштування Rakia/SofiaSIP
Name[wa]=Eterface uzeu d' apontiaedje des contes Rakia/SofiaSIP
Name[x-test]=xxRakia/SofiaSIP Account Configuration User Interfacexx
Name[zh_CN]=Rakia/SofiaSIP 账户用户配置界面
Name[zh_TW]=Rakia/SofiaSIP 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_rakia
X-KDE-PluginInfo-Author=Florian Reinhard
X-KDE-PluginInfo-Email=florian.reinhard@googlemail.com
X-KDE-PluginInfo-Name=rakia
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true

==> ktp-accounts-kcm-22.07.80.tar.xz: ktp-accounts-kcm-22.07.80/plugins/rakia/ktpaccountskcm_plugin_rakia.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Rakia/SofiaSIP connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći Rakia/Sofia SIP menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració del compte personalitzat per a comptes que usen el gestor de connexions Rakia/SofiaSIP.
Comment[ca@valencia]=Interfície d'usuari de configuració del compte personalitzat per a comptes que utilitzen el gestor de connexions Rakia/SofiaSIP.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Raika/SofiaSIP.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Rakia/SofiaSIP.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Rakia/SofiaSIP-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Rakia/SofiaSIP.
Comment[en_GB]=Custom account configuration user interface for accounts using the Rakia/SofiaSIP connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Rakia/SofiaSIP.
Comment[et]=Rakia/SofiaSIP-i ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[eu]=Kontuak konfiguratzeko norberak finkaturiko erabiltzaile interfazea «Rakia/SofiaSIP» konexio kudeatzailea erabiltzen duten kontuetarako.
Comment[fi]=Rakia/SofiaSIP-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Rakia / SofiaSIP ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Rakia/SofiaSIP.
Comment[hu]=Egyedi beállítófelület a Rakia/SofiaSIP kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Rakia/SofiaSIP.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Rakia/SofiaSIP.
Comment[kk]=Rakia/SofiaSIP байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី​ផ្ទាល់ខ្លួន​សម្រាប់​គណនី​ដែល​ប្រើ​កម្មវិធី​គ្រប់គ្រង​ការ​តភ្ជាប់ Rakia/SofiaSIP ។
Comment[ko]=Rakia/SofiaSIP 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Rakia/SofiaSIP ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Rakia/SofiaSIP tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „Rakia/SofiaSIP“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Rakia/SofiaSIP verbindingenbeheerder gebruiken.
Comment[nn]=Brukarflate for å setja oppkontoar med Raika/SofiaSP tilkoplingshandsamar.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń Rakia/SofiaSIP.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Rakia/SofiaSIP.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Rakia/SofiaSIP.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Rakia/SofiaSIP.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Rakia/SofiaSIP.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Rakia/SofiaSIP.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Rakia/SofiaSIP.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Ракија/СофијаСИП.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Ракија/СофијаСИП.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Rakia/SofiaSIP.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Rakia/SofiaSIP.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Rakia/SofiaSIP.
Comment[tr]=Rakia/SofiaSIP bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштування облікового запису за допомогою керування з’єднаннями Rakia/SofiaSIP.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes tot s' siervant do manaedjeu d' raloyaedje Rakia/SofiaSIP.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Rakia/SofiaSIP connection manager.xx
Comment[zh_CN]=通过 Rakia/SofiaSIP 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Rakia/SofiaSIP 連線管理員的帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Rakia/SofiaSIP Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Rakia/Sofia SIP
Name[ca]=Interfície d'usuari de configuració del compte de Rakia/SofiaSIP
Name[ca@valencia]=Interfície d'usuari de configuració del compte de Rakia/SofiaSIP
Name[cs]=Uživatelské rozhraní nastavení účtu Rakia/SofiaSIP
Name[da]=Brugerflade til Rakia/SofiaSIP kontokonfiguration
Name[de]=Benutzeroberfläche zur Einrichtung von Rakia/SofiaSIP-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη με Rakia/SofiaSIP
Name[en_GB]=Rakia/SofiaSIP Account Configuration User Interface
Name[es]=Interfaz de configuración de cuentas Rakia/SofiaSIP
Name[et]=Rakia/SofiaSIP-i konto seadistamise kasutajaliides
Name[eu]=«Rakia/SofiaSIP» kontuak konfiguratzeko erabiltzaile interfazea
Name[fi]=Rakia/SofiaSIP-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur pour la configuration de comptes « Rakia / SofiaSIP ».
Name[gl]=Interface de usuario para a configuración de contas de Rakia/SofiaSIP
Name[hu]=Rakia/SofiaSIP azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Rakia/SofiaSIP
Name[it]=Interfaccia utente di configurazione account Rakia/SofiaSIP
Name[kk]=Rakia/SofiaSIP тіркелгі пайдаланушы интерфейсін баптау
Name[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី Rakia/SofiaSIP
Name[ko]=Rakia/SofiaSIP 계정 설정 사용자 인터페이스
Name[lt]=Rakia/SofiaSIP paskyros konfigūravimo naudotojo sąsają
Name[nb]=Brukerflate for å sette opp Rakia/SofiaSIP-konto
Name[nds]=Rakia/SofiaSIP-Kontoinstellenböversiet
Name[nl]=Gebruikersinterface voor Rakia/SofiaSIP accountconfiguratie
Name[nn]=Brukarflate for å setja opp Radika/SofiaSIP-konto
Name[pl]=Nakładka graficzna do ustawiania konta Rakia/SofiaSIP
Name[pt]=Interface de Configuração de Contas do Rakia/SofiaSIP
Name[pt_BR]=Interface de configuração de contas do Rakia/SofiaSIP
Name[ro]=Interfață de configurare a conturilor Rakia/SofiaSIP
Name[ru]=Интерфейс для настройки учётной записи Rakia/SofiaSIP
Name[sk]=Používateľské rozhranie konfigurácie účtu Rakia/SofiaSIP
Name[sl]=Uporabniški vmesnik za nastavitev računov Rakia/SofiaSIP
Name[sr]=Корисничко сучеље за подешавање налога под Ракијом/СофијаСИП‑ом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Ракијом/СофијаСИП‑ом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod Rakijom/SofiaSIP‑om
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod Rakijom/SofiaSIP‑om
Name[sv]=Användargränssnitt för inställning av Rakia/SofiaSIP-konton
Name[tr]=Rakia/SofiaSIP Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштування Rakia/SofiaSIP
Name[wa]=Eterface uzeu d' apontiaedje des contes Rakia/SofiaSIP
Name[x-test]=xxRakia/SofiaSIP Account Configuration User Interfacexx
Name[zh_CN]=Rakia/SofiaSIP 账户用户配置界面
Name[zh_TW]=Rakia/SofiaSIP 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_rakia
X-KDE-PluginInfo-Author=Florian Reinhard
X-KDE-PluginInfo-Email=florian.reinhard@googlemail.com
X-KDE-PluginInfo-Name=rakia
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
